pub struct OptionalParserPackProofAggregate {
pub schema_version: u32,
pub pack_id: String,
pub projectatlas_version: String,
pub accepted_manifest_sha256: Sha256Digest,
pub capability_set_digest: Blake3Digest,
pub fixture_corpus_sha256: Sha256Digest,
pub platforms: Vec<OptionalParserPackPlatformProof>,
}Expand description
Exact supported-platform optional parser-pack proof aggregate.
Fields
schema_version: u32Aggregate schema version.
pack_id: StringStable logical pack identity.
projectatlas_version: StringIntended ProjectAtlas release line.
accepted_manifest_sha256: Sha256DigestSHA-256 of the shared accepted logical manifest bytes.
capability_set_digest: Blake3DigestShared logical accepted capability digest.
fixture_corpus_sha256: Sha256DigestSHA-256 of the shared retained fixture corpus bytes.
platforms: Vec<OptionalParserPackPlatformProof>Required platform receipts in canonical platform order.
Implementations
Sourceimpl OptionalParserPackProofAggregate
impl OptionalParserPackProofAggregate
Sourcepub fn validate(
&self,
logical: &OptionalParserPackManifest,
) -> Result<(), OptionalParserPackManifestError>
pub fn validate( &self, logical: &OptionalParserPackManifest, ) -> Result<(), OptionalParserPackManifestError>
Validate the exact required platform set and shared logical proof identity.
Errors
Returns an error for a missing, duplicate, failed, dirty, or logically divergent proof.