OptionalParserPackRegistryBinding

Struct OptionalParserPackRegistryBinding 

pub struct OptionalParserPackRegistryBinding {
    pub registry_version: u32,
    pub registry_digest: Blake3Digest,
    pub accepted_set_version: u32,
    pub accepted_set_digest: Blake3Digest,
}
Exact binding to the language registry that admitted optional candidates.

Fields

registry_version: u32

Language capability registry schema version.

registry_digest: Blake3Digest

Digest of achieved registry truth and detector rules.

accepted_set_version: u32

Accepted language capability-set version.

accepted_set_digest: Blake3Digest

Digest of accepted language minimums.

Implementations

Source

impl OptionalParserPackRegistryBinding

pub fn current() -> Result<Self, OptionalParserPackManifestError>

Capture the current authoritative language-registry identity.

Errors

Returns an error only if an internal registry digest is not canonical.